/*
 * jSite-next - ListenerSupport.java -
 * Copyright © 2008 David Roden
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package net.pterodactylus.util.event;

import java.util.ArrayList;
import java.util.EventListener;
import java.util.List;

/**
 * Helper class for {@link EventListener} management.
 *
 * @param <L>
 *            The type of the event listener
 * @author David Roden &lt;droden@gmail.com&gt;
 */
public class ListenerSupport<L extends EventListener> {

	/** The list of registered listeners. */
	private final List<L> listeners = new ArrayList<L>();

	/**
	 * Adds a listener to the list of registered listeners.
	 *
	 * @param listener
	 *            The listener to add
	 */
	public void addListener(L listener) {
		synchronized (listeners) {
			listeners.add(listener);
		}
	}

	/**
	 * Removes a listener from the list of registered listeners.
	 *
	 * @param listener
	 *            The listener to remove
	 */
	public void removeListener(L listener) {
		synchronized (listeners) {
			listeners.remove(listener);
		}
	}

	/**
	 * Returns a list of all listeners. This list is a copy of the internally
	 * kept list and as thus will not be modified by calls to
	 * {@link #addListener(EventListener)} or
	 * {@link #removeListener(EventListener)}.
	 *
	 * @return The list of all listeners
	 */
	protected List<L> getListeners() {
		synchronized (listeners) {
			return new ArrayList<L>(listeners);
		}
	}

	/* TODO */

}
